/*********************************************************************
 * FileName:        user.h
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18
 * Compiler:        C18 2.30.01+
 * Company:         sprut
 * Copyright:       2007-2010 Joerg Bredendiek (sprut)
 *
 *
 ********************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef USER_H
#define USER_H



/** I N C L U D E S **********************************************************/
#include "system\usb\usb.h"
#include "system\typedefs.h"


/** D E F I N I T I O N S ****************************************************/
/* 28-Pin-Testplatinen-Test Version */
#define MINOR_VERSION   0x07    //Firmware-Version = 07
#define MAJOR_VERSION   0x02    //USB4a            = 02



/** S T R U C T U R E S ******************************************************/

// IO, ADC

typedef union DATA_PACKET
{
    byte _byte[USBGEN_EP_SIZE];  	// for byte access
    word _word[USBGEN_EP_SIZE/2];	// for word access(USBGEN_EP_SIZE must be even)
    struct
    {
        enum
        {
            READ_VERSION    = 0x00,
            LED_ONOFF       = 0x31,
            READ_SWITCH     = 0x32,
            RD_ADC          = 0x37,
			SET_AN			= 0x38,

			SET_SIGNAL		= 0x3B,
			READ_DATA		= 0x3D,

			SET_ADRESS		= 0x42,
			SET_VPP			= 0x43,
			READ_EDATA		= 0x44,
			WRITE_EDATA		= 0x45,

			SYS_IO			= 0x50,
			SYS_ADC			= 0x51,


            RESET           = 0xFF
        }CMD;
        byte len;
    };
    struct
    {
        unsigned :8;
        byte ID;
    };
    struct
    {
        unsigned :8;
        word word_data;
    };
} DATA_PACKET;


//typedef char T_BESCH;



/** P U B L I C  P R O T O T Y P E S *****************************************/
void UserInit(void);
void ProcessIO(void);


/** P R I V A T E  P R O T O T Y P E S ***************************************/
void ServiceRequests(void);

void SleepUs(unsigned int us);
void SleepMs(unsigned int ms);

void readEdata(void);
void writeEdata(void);
void ReadADC(void);


void UP_IO(void);
void UP_ADC(void);
void ClearRelais(void);
void SetRelais(byte);

#endif	// USER_H

/****  E N D E  *********************************************/
